/**
    (C) Copyright 2012 Dominik Wagenfuehr

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "Bot.hh"
#include "IStrategy.hh"

// Konstruktor.
Bot::Bot()
  : mStrategyP(0), mPoints(0)
{ }

// Destruktor.
Bot::~Bot()
{
    delete mStrategyP;
}

// Setzt die Strategie (nachtraeglich) fuer einen Bot.
void Bot::setStrategy( IStrategy* strategyP )
{
    // Loesche alte Strategie.
    delete mStrategyP;

    // Es wird hier nicht auf einen Nullpointer geprueft.
    mStrategyP = strategyP;
}

// Akzeptiert oder lehnt ein Angebot ab.
bool Bot::acceptOffer( const int value )
{
    bool retValue = false;

    // Ist ueberhaupt eine Strategie definiert.
    if ( mStrategyP )
    {
        retValue = mStrategyP->acceptOffer( value );
    }

    if ( retValue )
    {
        // Wenn wir das Angebot annehmen, speichern
        // wir, wie viele Punkte wir erhalten haben.
        mPoints += value;
    }
    
    return retValue;
}

// Gibt die gesammelten Punkte zurueck.
int Bot::getPoints() const
{
    return mPoints;
}
